@@ -3,22 +3,24 @@
 package Pinto::DistributionSpec;
 
 use Moose;
-
+use MooseX::MarkAsMethods (autoclean => 1);
 use MooseX::Types::Moose qw(ArrayRef Str);
-use Pinto::Types qw(Author);
+
+use Pinto::Types qw(AuthorID);
+use Pinto::Util qw(throw);
 
 use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.064'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #------------------------------------------------------------------------------
 
 
 has author => (
     is       => 'ro',
-    isa      => Author,
+    isa      => AuthorID,
     required => 1,
 );
 
@@ -59,7 +61,7 @@ around BUILDARGS => sub {
         my $archive  = pop @path_parts;    # Last element
         my $subdirs  = [ @path_parts ];    # Everything else
 
-        confess "Invalid distribution spec: $args[0]"
+        throw "Invalid distribution spec: $args[0]"
             if not ($author and $archive);
 
         @args = (author => $author, subdirs => $subdirs, archive => $archive);
@@ -108,7 +110,7 @@ __PACKAGE__->meta->make_immutable;
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -120,7 +122,7 @@ Pinto::DistributionSpec - Specifies a distribution by author and path fragments
 
 =head1 VERSION
 
-version 0.064
+version 0.066
 
 =head1 METHODS
 
@@ -136,7 +138,7 @@ context.  Returns the same result as the C<path> method.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -146,7 +148,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
