@@ -3,15 +3,21 @@
 package Pinto::PackageSpec;
 
 use Moose;
-
+use MooseX::MarkAsMethods (autoclean => 1);
 use MooseX::Types::Moose qw(Str);
-use Pinto::Types qw(Vers);
 
+use Module::CoreList;
+use English qw(-no_match_vars);
+
+use Pinto::Types qw(Version);
+use Pinto::Util qw(throw);
+
+use version;
 use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.064'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -24,7 +30,7 @@ has name => (
 
 has version => (
     is      => 'ro',
-    isa     => Vers,
+    isa     => Version,
     coerce  => 1,
     default => sub { version->parse(0) }
 );
@@ -47,6 +53,33 @@ around BUILDARGS => sub {
 #------------------------------------------------------------------------------
 
 
+sub is_core {
+    my ($self, %args) = @_;
+
+    ## no critic qw(PackageVar);
+
+    my $pv = version->parse($args{in}) || $PERL_VERSION;
+    my $core_modules = $Module::CoreList::version{ $pv->numify + 0 };
+
+    throw "Invalid perl version $pv" if not $core_modules;
+
+    return 0 if not exists $core_modules->{$self->name};
+    return 0 if $self->version > $core_modules->{$self->name};
+    return 1;
+}
+
+#-------------------------------------------------------------------------------
+
+
+sub is_perl {
+    my ($self) = @_;
+
+    return $self->name eq 'perl' ? 1 : 0;
+}
+
+#-------------------------------------------------------------------------------
+
+
 sub to_string {
     my ($self) = @_;
     return sprintf '%s~%s', $self->name, $self->version->stringify;
@@ -59,7 +92,7 @@ __PACKAGE__->meta->make_immutable;
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -71,10 +104,22 @@ Pinto::PackageSpec - Specifies a package by name and version
 
 =head1 VERSION
 
-version 0.064
+version 0.066
 
 =head1 METHODS
 
+=head2 is_core
+
+=head2 is_core(in => $version)
+
+Returns true if this package is satisfied by the perl core as-of a particular
+version.  If the version is not specified, it defaults to whatever version
+you are using now.
+
+=head2 is_perl()
+
+Returns true if this package is perl itself.
+
 =head2 to_string()
 
 Serializes this PackageSpec to its string form.  This method is called
@@ -82,7 +127,7 @@ whenever the PackageSpec is evaluated in string context.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -92,7 +137,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
